@@ -153,7 +153,12 @@ def _add_ldap_user(username, password, uidNumber, homeDir):
 	attrs = {}
 	attrs['objectclass'] = ['top', 'account', 'posixAccount', 'shadowAccount']  
 	attrs['cn'] = username
-	attrs['userPassword'] = hubzero.config.passwords.MD5PasswordHash(password)
+
+	if password != '*':
+		attrs['userPassword'] = hubzero.config.passwords.MD5PasswordHash(password)
+	else:
+		attrs['userPassword'] = '{MD5}*' # can user generate a value that will MD5 hash to '*'?
+	
 	attrs['uid'] = username
 	attrs['uidNumber'] = str(uidNumber)
 	attrs['homeDirectory'] = homeDir
@@ -202,6 +207,9 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 		homeDir = '/home/' + hubname + "/" + username
 
 
+	if pwdisabled: 
+		pw = "*"
+
 	userID = _insert_jos_users(db, joomlauserid, fullname, username, email, pw, joomlagid, joomlagidNumber)
 	aroID = _insert_jos_core_acl_aro(db, userID, fullname)
 	_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
@@ -211,12 +219,11 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 
 	# create linux group for user named same as username
 	if createGroup:
-		rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["addgroup", username])
-		print procStdOut
-		if rc:
-			print procStdErr
+
 		gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
 		hubzero.utilities.group._insert_jos_xgroups_members(db, gidNumber, userID)
+
+		hubzero.utilities.group._add_ldap_group(username, username + " group", gidNumber)
 		
 
 	# create home directory
